"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = require("aws-sdk");
const transliterate_1 = require("./transliterate/transliterate");
const calculation_1 = require("./calculation/calculation");
const uuid_1 = require("uuid");
exports.transliterateHandler = (event, context, callback) => {
    let transliterator = new transliterate_1.Transliterator();
    console.log('Received event:', JSON.stringify(event));
    let inputParams = event.queryStringParameters;
    inputParams = inputParams !== null ? inputParams : { input: '' };
    let input = inputParams.input;
    let output = transliterator.transliterate(input);
    const response = {
        statusCode: 200,
        headers: { 'Access-Control-Allow-Origin': '*' },
        body: JSON.stringify(output)
    };
    callback(undefined, response);
};
exports.additionHandler = (event, context, callback) => {
    try {
        let calculator = new calculation_1.Calculator();
        console.log('Received event:', JSON.stringify(event));
        let requestBody = JSON.parse(event.body);
        let a = parseInt(requestBody.a, 10);
        let b = parseInt(requestBody.b, 10);
        let output = calculator.add(a, b);
        const response = {
            statusCode: 200,
            headers: { 'Access-Control-Allow-Origin': '*' },
            body: JSON.stringify(output)
        };
        callback(undefined, response);
    }
    catch (e) {
        handleError(e, callback);
    }
};
///////////////////////////////////////////////////
exports.createDynDBRecord = (event, context, callback) => {
    const dynamoDb = new aws_sdk_1.DynamoDB.DocumentClient();
    const timestamp = new Date().getTime();
    const data = JSON.parse(event.body);
    if (typeof data.text !== 'string') {
        console.error('Validation Failed');
        callback(undefined, {
            statusCode: 400,
            headers: { 'Content-Type': 'text/plain' },
            body: 'Couldn\'t create the todo item.',
        });
        return;
    }
    const params = {
        TableName: process.env.DYNAMODB_TABLE,
        Item: {
            id: uuid_1.v1(),
            text: data.text,
            checked: false,
            createdAt: timestamp,
            updatedAt: timestamp,
        },
    };
    aws_sdk_1.config.region = 'us-west-2';
    // write the todo to the database
    dynamoDb.put(params, (error) => {
        // handle potential errors
        if (error) {
            console.error(error);
            callback(undefined, {
                statusCode: error.statusCode || 501,
                headers: { 'Content-Type': 'text/plain' },
                body: 'Couldn\'t create the todo item.',
            });
            return;
        }
        // create a response
        const response = {
            statusCode: 200,
            body: JSON.stringify(params.Item),
        };
        callback(undefined, response);
    });
};
let handleError = function (error, callback) {
    const response = {
        statusCode: 500,
        body: JSON.stringify(error)
    };
    callback(error, response);
};
//# sourceMappingURL=handler.js.map