// handler.spec.ts
// import * as mocha from 'mocha';
import * as chai from 'chai';
import { APIGatewayEvent } from 'aws-lambda';
import { config } from 'aws-sdk';
import { transliterateHandler, createDynDBRecord } from '../src/handler';
const expect = chai.expect;

describe('handler', () => {
  describe('transliterate', () => {
    it('should return ohayougozaimasu', () => {
      const event: MockAPIEvent = new MockAPIEvent();
      event.queryStringParameters  = {input: 'おはようございます'};

      transliterateHandler(event, undefined, (error: Error, result: any) => {
        expect(result.body).to.be.equal('{"input":"おはようございます","output":"ohayougozaimasu"}');
      });
    });
  });
});

describe('handler', () => {
  describe('createrecord', () => {
    it('should create a record', () => {
      process.env.DYNAMODB_TABLE = 'aws-nodejs-test';
      config.region = 'us-west-2';
      const event: MockAPIEvent = new MockAPIEvent();
      event.body = JSON.stringify({
        text: 'test data'
      });

      createDynDBRecord(event, undefined, (error: Error, result: any) => {
        expect(JSON.parse(result.body)).to.not.be.null.and.to.have.property('id').to.not.be.null;
      });
    });
  });
});

////////////////
class MockAPIEvent implements APIGatewayEvent {
  body = '';
  headers = {};
  httpMethod = 'GET';
  isBase64Encoded = false;
  path = '';
  queryStringParameters = {};
  pathParameters = {};
  stageVariables = {};
  requestContext = undefined;
  resource = '';
}